4 ms·
They're using the Google Closure compiler as their minifier now. Resig in this presentation (warning: video autoplay), in response to the last question, said t
by mark_h 17y ago
They're using the Google Closure compiler as their minifier now.
Resig in this presentation (warning: video autoplay), in response to the last question, said that while it's slick if you simply throw jquery into it you'll just get broken javascript out: http://developer.yahoo.com/yui/theater/video.php?v=resig-testing http://developer.yahoo.com/yui/theater/video.php?v=resig-tes...
I wonder what has changed?
(Maybe just not running it in advanced mode; at any rate, they're reporting a 13% decrease in file size: http://github.com/jquery/jquery/commit/3fd62eae9df3159fc238a515bb748140a942313d http://github.com/jquery/jquery/commit/3fd62eae9df3159fc238a...)
- jeresig 17y agoYeah, we only use simple mode - it's advanced mode that everyone needs to watch out for - it doesn't do what you expect (it's optimized for combining multiple files, not producing one file).
- zackattack 17y ago# .val(“…”) on an option or a checkbox is no longer ambiguous (it will always select by value now, not by text value). (Commit) The hyperlink on "(Commit)" is broken.
- jeresig 17y agoGood catch, thanks.
- zackattack 17y agoThanks for jQuery :)
- mark_h 17y agoAwesome, thanks. (and just donated too; thanks again!)
- TeHCrAzY 17y agoIf you carefully read the instructions, you can learn how to compile libraries with it - there is explicit support for this use case. (which is likely what jQuery have done.) Exports: http://code.google.com/closure/compiler/docs/api-tutorial3.html#export http://code.google.com/closure/compiler/docs/api-tutorial3.h... Extern: http://code.google.com/closure/compiler/docs/api-tutorial3.html#externs http://code.google.com/closure/compiler/docs/api-tutorial3.h...
- jeresig 17y agoActually it's not really efficient for us to do that - since we would need to expose literally everything and in the end we would end up with the same result as running it through the simple minifier. As it turns out though the simple minifier is quite good - giving us a 13% improvement over YUI Min.